@@ -664,9 +664,6 @@
 # <https://www.gnu.org/licenses/>.
 
 import os
-from os.path import join, dirname
-
-# import pandas
 from dotenv import load_dotenv
 from sqlalchemy import create_engine
 
@@ -689,9 +686,8 @@ class Connection:
         get_engine():
             return engine data type for connected to postgresql
     """
-    def __init__(self, db_name):
-        dotenv_path = join(dirname(__file__), 'credential/.env')
-        load_dotenv(dotenv_path)
+    def __init__(self, db_name, env_file_location):
+        load_dotenv(env_file_location)
 
         # SATUDATA
         username = os.environ.get('DB_SATUDATA_USERNAME')
